from django.shortcuts import render
from .models import Personne
from django.shortcuts import render, redirect
from .models import Personne

def index(request):
    if request.method == 'POST':
        nom_prenom = request.POST.get('nom_prenom')
        email = request.POST.get('email')
        adresse = request.POST.get('adresse')
        numero = request.POST.get('numero')
        profile = request.POST.get('profile')
        formation = request.POST.get('formation')
        experience = request.POST.get('experience')

        # Créer l'objet Personne
        personne = Personne.objects.create(
            nom_prenom=nom_prenom,
            email=email,
            adresse=adresse,
            numero=numero,
            profile=profile,
            formation=formation,
            experience=experience,
        )

        # Rediriger vers la page de résultat avec l'id
        return redirect('lookup', id=personne.id)

    return render(request, "django_cv1/moncv.html")


def lookup(request, id):
    personne = Personne.objects.get(id=id)
    return render(request, "django_cv1/lookup1.html", {"cv": personne})



# Generated by Django 5.2.4 on 2025-07-25 07:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_cv1', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='personne',
            name='nom_prenom',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='adresse',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='email',
            field=models.EmailField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='experience',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='formation',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='numero',
            field=models.CharField(blank=True, max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='profile',
            field=models.TextField(blank=True, null=True),
        ),
    ]



from django.db import models

from django.db import models


class Personne(models.Model):
    nom_prenom = models.CharField(max_length=200 , blank=True, null=True)
    email = models.EmailField(max_length=200 ,blank=True, null=True)
    adresse = models.CharField(max_length=200, blank=True, null=True)
    numero = models.CharField(max_length=20, blank=True, null=True)
    profile = models.TextField(blank=True, null=True)
    experience = models.TextField(blank=True, null=True)
    formation = models.TextField(blank=True, null=True)

